@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 """
 MIDI Objects for Python
 
@@ -28,12 +27,12 @@ Parsing MIDI streams:
     parse_all(bytes) -- parse all messages bytes
     Parser -- MIDI parser class
 
-Parsing objects serialized with str(message):
+Parsing objects serialized with str(message):                                  
 
     parse_string(string) -- parse a string containing a message
     parse_string_stream(iterable) -- parse strings from an iterable and
                                      generate messages
-
+ 
 Sub modules:
 
     ports -- useful tools for working with ports
@@ -74,17 +73,47 @@ Getting started:
     >>> get_input_names()
     ['MPK mini MIDI 1', 'SH-201']
 """
-from . import ports
-from .messages import Message, parse_string, parse_string_stream
+from __future__ import absolute_import
+import os
+from .backends import Backend
+from . import ports, sockets
+from .messages import Message
+from .messages import parse_string, parse_string_stream, format_as_string
 from .parser import Parser, parse, parse_all
-from .portmidi import open_input, open_output, open_ioport
-from .portmidi import get_input_names, get_output_names, get_ioport_names
 
 __author__ = 'Ole Martin Bjørndalen'
 __email__ = 'ombdalen@gmail.com'
 __url__ = 'http://mido.readthedocs.org/'
 __license__ = 'MIT'
-__version__ = '1.0.4'
+__version__ = '1.1.0'
 
 # Prevent splat import.
 __all__ = []
+
+def set_backend(name=None):
+    """Set current backend.
+
+    name can be a module name like 'mido.backends.rtmidi' or
+    a Backend object.
+
+    If no name is passed, the default backend will be used.
+
+    This will replace all the open_*() and get_*_name() functions
+    in top level mido module. The module will be loaded the first
+    time one of those functions is called."""
+
+    glob = globals()
+
+    if isinstance(name, Backend):
+        backend = name
+    else:
+        backend = Backend(name, load=False, use_environ=True)
+    glob['backend'] = backend
+
+    for name in dir(backend):
+        if name.split('_')[0] in ['open', 'get']:
+            glob[name] = getattr(backend, name)
+
+set_backend()
+
+del os, absolute_import
